<?php

namespace Modules\OffersNetwork\Http\Services\Providers;

use App\Models\OfferSetup;
use Modules\OffersNetwork\Entities\OffersStorage;
use Modules\OffersNetwork\Http\Services\FetchOffersService;

class CPXResearch extends FetchOffersService
{
    public  static function get()
    {

        $provider = OfferSetup::findOrFail(10);

        if ($provider->is_active == 0 || $provider->en_api == 0) {
            OffersStorage::where('provider_id', $provider->id)->delete();
            return [];
        }

        $url = 'https://live-api.cpx-research.com/api/get-surveys.php?';

        $params = [
            'app_id' => $provider->offer_keys->app_id,
            'ext_user_id' => '{user}',
            'output_method' => 'api',
            'ip_user' => is_local() == false ? getUserIP() : '156.221.24.105',
            'user_agent' => rawurlencode($_SERVER['HTTP_USER_AGENT']),
        ];

        $response = self::curlGet($url . http_build_query($params));

        if ($response['statusCode'] === 200 && isset($response['data']['surveys'])) {
            self::storeOffers($response['data']['surveys'], $provider);
        }
        
        return 'done';
    }

    public  static function storeOffers($offers, $provider)
    {
        $userCountry = is_local() ? 'EG' : getIpInfo()['code'];
        
        OffersStorage::where('provider_id', $provider->id)->delete();

        foreach ($offers as $offer) {

            OffersStorage::updateOrCreate(
                [
                    'provider_id' => $provider->id,
                    'uid' => $offer['id'],
                ],
                [
                    'name' => 'Online Surveys',
                    'description' => 'Complete the survey to get paid',
                    'image' => asset('/asset/static/app/imgs/loading.gif'),
                    'rewards' => $offer['payout_publisher_usd'] * GENERAL_SETTING['cur_rate'],
                    'payout' => $offer['payout_publisher_usd'],
                    'click_url' => $offer['href_new'],
                    'category' => 'survey',
                    'country' => $userCountry,
                    'device' => self::mapDevices(['all']),
                ]
            );
        }


    }
}
