<?php

namespace Modules\OffersNetwork\Http\Services\Providers;

use App\Models\OfferSetup;
use Modules\OffersNetwork\Entities\OffersStorage;
use Modules\OffersNetwork\Http\Services\FetchOffersService;

class Kiwiwall extends FetchOffersService
{
    public  static function get()
    {

        $provider = OfferSetup::findOrFail(11);

        if ($provider->is_active == 0 || $provider->en_api == 0) {
            OffersStorage::where('provider_id', $provider->id)->delete();
            return [];
        }

        $url = 'https://www.kiwiwall.com/get-offers/' . $provider->offer_keys->api_key . '?';

        $params = [
            'country' => is_local() ? 'EG' : getIpInfo()['code'],
            's' => '{user}'
        ];


        $response = self::curlGet($url . http_build_query($params));

        if ($response['statusCode'] === 200 && isset($response['data'])) {
            self::storeOffers($response['data'], $provider);
        }
        return 'done';
    }

    public  static function storeOffers($offers, $provider)
    {

        OffersStorage::where('provider_id', $provider->id)->delete();

        foreach ($offers['offers'] as $offer) {

            OffersStorage::updateOrCreate(
                [
                    'provider_id' => $provider->id,
                    'uid' => $offer['id'],
                ],
                [
                    'name' => $offer['name'],
                    'description' => $offer['instructions'],
                    'image' => $offer['logo'],
                    'rewards' => $offer['cr'] * GENERAL_SETTING['cur_rate'],
                    'payout' => $offer['cr'],
                    'click_url' => $offer['link'],
                    'category' => strtolower($offer['category']),
                    'country' => $offers['country'],
                    'device' => self::mapDevices(['ALL']),
                ]
            );
        }

    }
}
