<?php

namespace App\Http\Middleware;

use Closure;
use App\Models\User;
use App\Models\UserLogin;
use Illuminate\Support\Str;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Session;
use Illuminate\Support\Facades\Http;

class CheckStatus
{
    public function handle($request, Closure $next)
    {
        $userIp = getUserIP();
        $cacheIp = cache()->get($userIp);
        $user = auth()->user();
        
        ####### ignore validation for admin ####
        if($user->role == 1 || $user->active_status_by_admin == 1){
            cache()->forever($userIp, "MASTER_IP");
            User::where('id', $user->id)->update(['updated_at' => now()]);
            return $next($request);
        }
        
        ####### check if user is banned ####
        if($user->status == 0){
            auth()->logout();
            return redirect()->route('user.login')->withNotify([['error', 'Your account has been banned!!., due to ' . $user->ban_reason]]);
        }
        
        ####### check if user has multipe account ####
        if($this->checkMultipleAccounts($userIp, $user) === true){
            auth()->logout();
            return redirect()->route('user.login')->withNotify([['error', 'Multipe account is not allowed']]);
        }
        
        ####### check if countrey is blocked ####
        if($cacheIp == "BLOCKED_COUNTRY" || $this->isBlockedCountry() === true){
            auth()->logout();
            return redirect()->route('user.login')->withNotify([['error', 'Your country are not allowed']]);
        }
        
        ####### check authorization ####
        if (!$user->ev || !$user->tv) {
            return redirect()->route('user.authorization');
        }
        
        ####### check if ip is using vps ####
        if($cacheIp == "VALID_IP" || (bool)SETTING['detect_using_vpn'] === false){
            return $next($request);
        }
        
        ####### check if ip is using vps ####
        if(($cacheIp == "BAD_IP" || $this->checkProxy($userIp, $user) === true) && (bool)SETTING['detect_using_vpn'] === true){
            auth()->logout();
            return redirect()->route('user.login')->withNotify([['error', 'Using VPN/Proxy/Bad IP is not allowed']]);
        }
        

        return $next($request);
    }
    
    protected function isBlockedCountry()
    {
        $countryCode = getIpInfo()['code'];
        if ($countryCode && Str::contains(SETTING['blocked_country'], $countryCode)) {
            cache()->forever(getUserIP(), "BLOCKED_COUNTRY");
            return true;
        }
        
        return false;
    }

    protected function checkProxy($userIp, $user)
    {
            $isProxy = $this->ipQualityScore($userIp);

            if ($isProxy === true) {
                if ((bool)SETTING['auto_ban_using_vpn'] === true) {
                    User::where('id', $user->id)->update(['status' => 0, 'ban_reason' => 'Using VPN/Proxy']);
                }
                return true;
            }
        return false;
    }


    protected function checkMultipleAccounts($userIp, $user)
    {
        $userIds = UserLogin::where('user_ip', $userIp)
                                ->pluck('user_id');
                                
        if ((bool)SETTING['single_account_per_ip'] == true && $userIds->unique()->count() > 1 ) {
            
            if ((bool)SETTING['auto_ban_multiple_accounts'] == true) {
                   UserLogin::where('user_ip', $userIp)->get()->each(function ($login) use ($userIds) {
                    User::whereIn('id', $userIds)->update(['status' => 0, 'ban_reason' => 'multiple accoounts']);
                });
            }
            
           return true;
        }
        
        return false;
    }

    protected function ipQualityScore($userIp)
    {
        
        $isBadIP  = false;
        
        $endPoint = 'https://www.ipqualityscore.com/api/json/ip/';
        $apiKey = SETTING['proxycheck_io_api'];
        $url = $endPoint . $apiKey . '/' . $userIp;
        
        $request = Http::withoutVerifying() // ignore ssl validation
            			->timeout(3)        // set timeout request ex:3s
                        ->retry(3, 100)     // set retry to resnd the request
                        ->withHeaders([		// array of headers with the request
                        	'Accept: application/json',
                            'Content-Type: application/json',
                            'Cache-Control: no-cache',
                            'Connection: close'        			
                        ])
            			->get($url, [         // array of request query
                        	'strictness' => 1,
                            'fast' => true,
                            'user_agent' => urlencode(request()->server('HTTP_USER_AGENT')),
                            'allow_public_access_points' => true,
                            'lighter_penalties' => true
                        ]);

        $response = $request->json();

        if ($response && $response['proxy']) {
            $isBadIP  =  $response['proxy'] || $response['tor'] || $response['vpn'] || $response['active_vpn'] || $response['active_tor'];
        }
        
        if($isBadIP  === true){
            cache()->forever($userIp, 'BAD_IP');
        }else{
            cache()->forever($userIp, 'VALID_IP');
        }

        return $isBadIP;
    }

}
