<?php

namespace App\Http\Middleware;

use Closure;
use App\Models\User;
use App\Models\UserLogin;
use Illuminate\Support\Str;
use Illuminate\Support\Facades\Auth;


class CheckStatus
{


    public function handle($request, Closure $next)
    {
        
        $userIp = getUserIP();
        
        $user = auth()->check() ? auth()->user() : null ;
        
        // validate the proxy proccess
        
        if (
            ($user !== null)
            && ($user->role == 0)
            && (session()->get('clean_ip') != $userIp)
            && (session()->get('bad_ip') != $userIp)
            && (SETTING['detect_using_vpn'] === 'on')
            ) {
            
            $proxyCheckRequest = $this->ipQualityScore();
            
            if ($proxyCheckRequest === true) {
                session()->put('bad_ip' , $userIp);
                if (SETTING['auto_ban_using_vpn'] == 'on' ) {
                    User::where('id', $user->id)->where('role', 0)->update(['status' => 0]);
                }
            } else
                session()->put('clean_ip' , $userIp);
        }

        // abort the use if he use VPN
        if (session()->get('bad_ip') == $userIp && SETTING['detect_using_vpn'] == 'on'  && $user->role == 0){
            abort(403, 'We are sorry, Using VPS is blocked');
        }

        // // abort user if his country blocked
        if (Str::contains(SETTING['blocked_country'], @getIpInfo()['code']) && $user->role == 0) {
            abort(403, 'We are sorry, your country is blocked');
        }
        
        
        // // validate the user ip with muliple account
        $accountsHaveSameIP = UserLogin::where('user_ip', $userIp)->get();
        
        if($accountsHaveSameIP->count('user_id') > 1 && boolval(SETTING['single_account_per_ip']) === true && $user !== null && $user->role == 0){
            
            if(boolval(SETTING['auto_ban_multiple_accounts']) === true){
                
                foreach($accountsHaveSameIP as $account){
                    $account->user->status = 0;
                    $account->user->save();
                }
            }
            
            auth()->logout();
            return redirect()->route('user.login')->withNotify([['danger', 'Multiple accounts is not allowed']]);
            
        }

        // // validate the user email validation 
        if (Auth::check()) {
            $user = auth()->user();
            if ($user->ev && $user->tv) {
                User::where('id', $user->id)->update(['updated_at' => now()]);
                return $next($request);
            } else {
                return redirect()->route('user.authorization');
            }
        }

        return $next($request);
    }


    protected function ipQualityScore()
    {

        $endPoint = 'https://www.ipqualityscore.com/api/json/ip/';

        $key = SETTING['proxycheck_io_api'] . '/';

        $ip = getUserIP() . '?';

        $parameters = [
            'strictness' => 1,
            'fast' => true,
            'user_agent' => urlencode(request()->server('HTTP_USER_AGENT')),
            'allow_public_access_points' => true,
            'lighter_penalties' => true,
        ];

        $url = $endPoint . $key  . $ip  . http_build_query($parameters);

        $request = curlContent($url);

        $response = json_decode($request, true);

        if (isset($response['success']) && $response['success'] == true) {
            if ($response['fraud_score'] > 25){
                return $response['proxy'] == true
                || $response['tor'] == true
                || $response['vpn'] == true
                || $response['active_vpn'] == true
                || $response['active_tor'] == true;
            }
            return false;
        }

        return false;
    }
}
