<?php

namespace App\Http\Requests;

use App\Rules\FileTypeValidate;
use Illuminate\Foundation\Http\FormRequest;

class OfferRequest extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     *
     * @return bool
     */
    public function authorize()
    {
        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array
     */
    public function rules()
    {
        if (request('is_builtin')) {
            $customParams = [
                'offer_keys' => ['required', 'array'],
                'en_api' => ['nullable'],
            ];
        } else {
            $customParams = [
                'offer_params' => ['required', 'array'],
            ];
        }

        $defaultParams = [
            'name' => ['required', 'string', 'min:2', 'max:191'],
            'bgcolor' => ['required', 'string', 'min:2', 'max:191'],
            'image' => !$this->offer_id && request('image') != null
            ? ['required', 'image', new FileTypeValidate(['png', 'jpg'])]
                : 'nullable',
            'iframe_url' => ['required', 'string', 'min:5'],
            'is_active' => 'nullable',
            'is_auto_pay' => 'nullable',
            'is_available' => 'nullable',
            'bonus' => ['required', 'numeric', 'gte:0', 'lte:100'],
            'rate' => ['required', 'numeric', 'gte:0', 'lte:5'],
            'position' => ['required', 'numeric', 'gte:0', 'lte:999'],
            'section' => ['required', 'string', 'in:offerwall,survey'],
        ];

        return array_merge($customParams, $defaultParams);
    }
}
